summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcameraedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcameraedit.h')
-rw-r--r--kpovmodeler/pmcameraedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmcameraedit.h b/kpovmodeler/pmcameraedit.h
index 33b9c39b..1ca18eb7 100644
--- a/kpovmodeler/pmcameraedit.h
+++ b/kpovmodeler/pmcameraedit.h
@@ -45,9 +45,9 @@ class PMCameraEdit : public PMNamedObjectEdit
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMCameraEdit with tqparent and name
*/
- PMCameraEdit( TQWidget* tqparent, const char* name = 0 );
+ PMCameraEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -45,9 +45,9 @@ class PMCameraEdit : public PMNamedObjectEdit
public:
/**
- * Creates a PMCameraEdit with tqparent and name
+ * Creates a PMCameraEdit with parent and name
*/